@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.36';
+  $CPAN::Perl::Releases::VERSION = '0.38';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -232,6 +232,10 @@ our $data =
     "tar.bz2" => "F/FL/FLORA/perl-5.15.4.tar.bz2",
     "tar.gz" => "F/FL/FLORA/perl-5.15.4.tar.gz",
   },
+  "5.15.5" => {
+    "tar.bz2" => "S/SH/SHAY/perl-5.15.5.tar.bz2",
+    "tar.gz" => "S/SH/SHAY/perl-5.15.5.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -340,7 +344,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.36
+version 0.38
 
 =head1 SYNOPSIS
 
